pub struct ScissorRect {
pub x: Line,
pub y: Line,
}Expand description
Defines a rectangle that can be used to limit the rendering area
Fields
x: Liney: LineImplementations
Sourceimpl ScissorRect
impl ScissorRect
Sourcepub fn from_corners(
top_left: Vec2<u32>,
bottom_right: Vec2<u32>,
) -> Option<Self>
pub fn from_corners( top_left: Vec2<u32>, bottom_right: Vec2<u32>, ) -> Option<Self>
Assumes a coordinate system alignment with (0, 0) being the top-right corner This is the case for Teeworlds/DDNet maps
Sourcepub fn intersect(&self, other: &Self) -> Option<Self>
pub fn intersect(&self, other: &Self) -> Option<Self>
Returns the area of the viewport that both ScissorRects cover
If they do not intersect, None is returned
pub fn apply(&self, render_pass: &mut RenderPass<'_>)