pub struct SpriteRenderContext<'a> {
pub clock: &'a Clock,
pub from_snap: &'a Snap,
pub to_snap: &'a Snap,
pub tees: &'a mut TeeStorage,
pub map: &'a Map,
pub particles: &'a mut Particles,
pub textures: &'a SpriteTextures,
pub rng: &'a mut Rng,
}Fields
clock: &'a Clockfrom_snap: &'a Snapto_snap: &'a Snaptees: &'a mut TeeStoragemap: &'a Mapparticles: &'a mut Particlestextures: &'a SpriteTexturesrng: &'a mut RngImplementations
Sourceimpl<'a> SpriteRenderContext<'a>
impl<'a> SpriteRenderContext<'a>
pub fn snap_sprite_generator(&'a mut self) -> SnapSpriteGenerator<'a>
Sourceimpl SpriteRenderContext<'_>
impl SpriteRenderContext<'_>
Sourcepub fn process_events(&mut self)
pub fn process_events(&mut self)
Process the events in the from-Snap.
Should be called whenever a new snap is introduced.
Also detects events through differences between the two snaps.